==> glass-2023.2.tar.gz: glass-2023.2/README.md <==

**GLASS**: Generator for Large Scale Structure
==============================================

[![Documentation](https://readthedocs.org/projects/glass/badge/?version=latest)](https://glass.readthedocs.io/en/latest/)
[![PyPI](https://img.shields.io/pypi/v/glass)](https://pypi.org/project/glass)
[![arXiv](https://img.shields.io/badge/arXiv-2302.01942-red)](https://arxiv.org/abs/2302.01942)
[![adsabs](https://img.shields.io/badge/ads-2023arXiv230201942T-blueviolet)](https://ui.adsabs.harvard.edu/abs/2023arXiv230201942T)
[![doi](https://img.shields.io/badge/doi-10.48550/arXiv.2302.01942-blue)](https://dx.doi.org/10.48550/arXiv.2302.01942)
[![Slack](https://img.shields.io/badge/join-Slack-4A154B)](https://glass-dev.github.io/slack)

This is the core library for GLASS, the Generator for Large Scale Structure.
For more information, see the full [documentation].  There are a number of
[examples] to get you started.


Installation
------------

Releases of the code can be installed with pip as usual:

    pip install glass

If you are interested in the latest version of the code, you can pip-install
this repository:

    pip install git+https://github.com/glass-dev/glass.git


Citation
--------

If you use GLASS simulations or the GLASS library in your research, please [cite
the original GLASS paper](CITATION.md) in your publications.


Getting in touch
----------------

The best way to get help about the code is currently to get in touch.

If you would like to start a discussion with the wider GLASS community about
e.g. a design decision or API change, you can use our [Discussions] page.

We also have a public [Slack workspace] for discussions about the project.


[documentation]: https://glass.readthedocs.io/
[examples]: https://glass.readthedocs.io/projects/examples/
[Discussions]: https://github.com/orgs/glass-dev/discussions
[Slack workspace]: https://glass-dev.github.io/slack

==> glass-2023.7.tar.gz: glass-2023.7/README.md <==

**GLASS**: Generator for Large Scale Structure
==============================================

[![Documentation](https://readthedocs.org/projects/glass/badge/?version=latest)](https://glass.readthedocs.io/en/latest/)
[![PyPI](https://img.shields.io/pypi/v/glass)](https://pypi.org/project/glass)
[![arXiv](https://img.shields.io/badge/arXiv-2302.01942-red)](https://arxiv.org/abs/2302.01942)
[![adsabs](https://img.shields.io/badge/ads-2023OJAp....6E..11T-blueviolet)](https://ui.adsabs.harvard.edu/abs/2023OJAp....6E..11T)
[![doi](https://img.shields.io/badge/doi-10.21105/astro.2302.01942-blue)](https://dx.doi.org/10.21105/astro.2302.01942)
[![Slack](https://img.shields.io/badge/join-Slack-4A154B)](https://glass-dev.github.io/slack)

This is the core library for GLASS, the Generator for Large Scale Structure.
For more information, see the full [documentation].  There are a number of
[examples] to get you started.


Installation
------------

Releases of the code can be installed with pip as usual:

    pip install glass

If you are interested in the latest version of the code, you can pip-install
this repository:

    pip install git+https://github.com/glass-dev/glass.git


Citation
--------

If you use GLASS simulations or the GLASS library in your research, please [cite
the original GLASS paper](CITATION.md) in your publications.


Getting in touch
----------------

The best way to get help about the code is currently to get in touch.

If you would like to start a discussion with the wider GLASS community about
e.g. a design decision or API change, you can use our [Discussions] page.

We also have a public [Slack workspace] for discussions about the project.

To keep up with new GLASS releases, you can receive GitHub release
notifications from this repository.  Alternatively, you can subscribe to our
announcement mailing list, which only receives 1 email/release.  To subscribe,
use the [mailing list page], or send an email to `listserv@jiscmail.ac.uk` with
any subject and the following message body:

    subscribe glass <Your name>

where `<Your name>` is your full name, or `ANONYMOUS` if you prefer. You will
be sent a confirmation email in return.


[documentation]: https://glass.readthedocs.io/
[examples]: https://glass.readthedocs.io/projects/examples/
[Discussions]: https://github.com/orgs/glass-dev/discussions
[Slack workspace]: https://glass-dev.github.io/slack
[mailing list page]: https://jiscmail.ac.uk/lists/GLASS.html
